#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-cKgZ5TzxslJq7L2lAumGT
key:                  criterion-measurement-0.2.3.0-cKgZ5TzxslJq7L2lAumGT
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  2912b7a049fa6c4e2548095d860b455a
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-cKgZ5TzxslJq7L2lAumGT
depends:
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-prim-0.10.0
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

